@@ -28,7 +28,6 @@ from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.dataproc import exceptions
 from googlecloudsdk.api_lib.dataproc import storage_helpers
 from googlecloudsdk.calliope import arg_parsers
-from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.export import util as export_util
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
@@ -449,25 +448,11 @@ def WaitForJobTermination(dataproc,
       'Job [{0}] timed out while in state [{1}].'.format(job_ref.jobId, state))
 
 
-# TODO(b/137899555): Remove and hard fail
-def ReturnDefaultRegionAndWarn():
-  log.warning('Dataproc --region flag will become required in January 2020. '
-              'Please either specify this flag, or set default by running '
-              "'gcloud config set dataproc/region <your-default-region>'")
-  return 'global'
-
-
 # This replicates the fallthrough logic of flags._RegionAttributeConfig.
 # It is necessary in cases like the --region flag where we are not parsing
 # ResourceSpecs
-def ResolveRegion(release_track):
-  region_prop = properties.VALUES.dataproc.region
-  if (release_track == base.ReleaseTrack.GA and
-      not region_prop.IsExplicitlySet()):
-    return ReturnDefaultRegionAndWarn()
-  else:
-    # Enforce flag or default value is required.
-    return region_prop.GetOrFail()
+def ResolveRegion():
+  return properties.VALUES.dataproc.region.GetOrFail()
 
 
 # You probably want to use flags.AddClusterResourceArgument instead.
@@ -479,7 +464,7 @@ def ParseCluster(name, dataproc):
   ref = dataproc.resources.Parse(
       name,
       params={
-          'region': lambda: ResolveRegion(dataproc.release_track),
+          'region': ResolveRegion,
           'projectId': properties.VALUES.core.project.GetOrFail
       },
       collection='dataproc.projects.regions.clusters')
@@ -495,7 +480,7 @@ def ParseJob(job_id, dataproc):
   ref = dataproc.resources.Parse(
       job_id,
       params={
-          'region': lambda: ResolveRegion(dataproc.release_track),
+          'region': ResolveRegion,
           'projectId': properties.VALUES.core.project.GetOrFail
       },
       collection='dataproc.projects.regions.jobs')
@@ -516,7 +501,7 @@ def ParseRegion(dataproc):
   ref = dataproc.resources.Parse(
       None,
       params={
-          'regionId': lambda: ResolveRegion(dataproc.release_track),
+          'regionId': ResolveRegion,
           'projectId': properties.VALUES.core.project.GetOrFail
       },
       collection='dataproc.projects.regions')
