@@ -169,6 +169,14 @@ def AddPromptForPassword(parser):
             'including the RETURN or ENTER key.'))
 
 
+def AddType(parser):
+  parser.add_argument('--type', help='Cloud SQL user\'s type. It determines '
+                      'the method to authenticate the user during login. '
+                      'See the list of user types at '
+                      'https://cloud.google.com/sql/docs/postgres/admin-api/'
+                      'v1beta4/users#type')
+
+
 # Instance create and patch flags
 
 
@@ -776,9 +784,17 @@ TIERS_FORMAT = """
   )
 """
 
-USERS_FORMAT_BETA = """
+USERS_FORMAT = """
   table(
     name.yesno(no='(anonymous)'),
     host
   )
 """
+
+USERS_FORMAT_ALPHA = """
+  table(
+    name.yesno(no='(anonymous)'),
+    host,
+    type.yesno(no='NATIVE')
+  )
+"""
