@@ -20,6 +20,7 @@ from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.ml_engine import models
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.ml_engine import endpoint_util
 from googlecloudsdk.command_lib.ml_engine import flags
 from googlecloudsdk.command_lib.ml_engine import models_util
 from googlecloudsdk.core import resources
@@ -50,4 +51,5 @@ class List(base.ListCommand):
     flags.GetRegionArg('model').AddToParser(parser)
 
   def Run(self, args):
-    return models_util.List(models.ModelsClient())
+    with endpoint_util.MlEndpointOverrides(region=args.region):
+      return models_util.List(models.ModelsClient())
