@@ -20,6 +20,7 @@ from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.ml_engine import operations
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.ml_engine import endpoint_util
 from googlecloudsdk.command_lib.ml_engine import flags
 from googlecloudsdk.command_lib.ml_engine import operations_util
 
@@ -42,4 +43,6 @@ class List(base.ListCommand):
     flags.GetRegionArg('operation').AddToParser(parser)
 
   def Run(self, args):
-    return operations_util.List(operations.OperationsClient())
+    with endpoint_util.MlEndpointOverrides(region=args.region):
+      client = operations.OperationsClient()
+      return operations_util.List(client)
