@@ -21,6 +21,7 @@ from __future__ import unicode_literals
 from googlecloudsdk.api_lib.ml_engine import operations
 from googlecloudsdk.api_lib.ml_engine import versions_api
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.ml_engine import endpoint_util
 from googlecloudsdk.command_lib.ml_engine import flags
 from googlecloudsdk.command_lib.ml_engine import versions_util
 from googlecloudsdk.command_lib.util.args import labels_util
@@ -113,11 +114,11 @@ class CreateGA(base.CreateCommand):
     _AddCreateArgs(parser)
 
   def Run(self, args):
-    versions_client = versions_api.VersionsClient()
-    labels = versions_util.ParseCreateLabels(versions_client, args)
+    client = versions_api.VersionsClient()
+    labels = versions_util.ParseCreateLabels(client, args)
     framework = flags.FRAMEWORK_MAPPER.GetEnumForChoice(args.framework)
     return versions_util.Create(
-        versions_client,
+        client,
         operations.OperationsClient(),
         args.version,
         model=args.model,
@@ -152,12 +153,12 @@ class CreateBeta(CreateGA):
     flags.AddExplainabilityFlags(parser)
 
   def Run(self, args):
-    versions_client = versions_api.VersionsClient()
-    labels = versions_util.ParseCreateLabels(versions_client, args)
+    client = versions_api.VersionsClient()
+    labels = versions_util.ParseCreateLabels(client, args)
     framework = flags.FRAMEWORK_MAPPER.GetEnumForChoice(args.framework)
     accelerator = flags.ParseAcceleratorFlag(args.accelerator)
     return versions_util.Create(
-        versions_client,
+        client,
         operations.OperationsClient(),
         args.version,
         model=args.model,
@@ -191,28 +192,30 @@ class CreateAlpha(CreateBeta):
   """
 
   def Run(self, args):
-    versions_client = versions_api.VersionsClient()
-    labels = versions_util.ParseCreateLabels(versions_client, args)
-    framework = flags.FRAMEWORK_MAPPER.GetEnumForChoice(args.framework)
-    accelerator = flags.ParseAcceleratorFlag(args.accelerator)
-    return versions_util.Create(versions_client,
-                                operations.OperationsClient(),
-                                args.version,
-                                model=args.model,
-                                origin=args.origin,
-                                staging_bucket=args.staging_bucket,
-                                runtime_version=args.runtime_version,
-                                config_file=args.config,
-                                asyncronous=args.async_,
-                                labels=labels,
-                                description=args.description,
-                                machine_type=args.machine_type,
-                                framework=framework,
-                                python_version=args.python_version,
-                                prediction_class=args.prediction_class,
-                                package_uris=args.package_uris,
-                                service_account=args.service_account,
-                                accelerator_config=accelerator,
-                                explanation_method=args.explanation_method,
-                                num_integral_steps=args.num_integral_steps,
-                                num_paths=args.num_paths)
+    with endpoint_util.MlEndpointOverrides(region=args.region):
+      client = versions_api.VersionsClient()
+      labels = versions_util.ParseCreateLabels(client, args)
+      framework = flags.FRAMEWORK_MAPPER.GetEnumForChoice(args.framework)
+      accelerator = flags.ParseAcceleratorFlag(args.accelerator)
+      return versions_util.Create(
+          client,
+          operations.OperationsClient(),
+          args.version,
+          model=args.model,
+          origin=args.origin,
+          staging_bucket=args.staging_bucket,
+          runtime_version=args.runtime_version,
+          config_file=args.config,
+          asyncronous=args.async_,
+          labels=labels,
+          description=args.description,
+          machine_type=args.machine_type,
+          framework=framework,
+          python_version=args.python_version,
+          prediction_class=args.prediction_class,
+          package_uris=args.package_uris,
+          service_account=args.service_account,
+          accelerator_config=accelerator,
+          explanation_method=args.explanation_method,
+          num_integral_steps=args.num_integral_steps,
+          num_paths=args.num_paths)
