@@ -59,7 +59,8 @@ class SetAutoscaling(base.Command):
                                resources,
                                igm_ref,
                                args,
-                               scale_in=False):
+                               scale_in=False,
+                               predictive=False):
     autoscaler = managed_instance_groups_utils.AutoscalerForMigByRef(
         client, resources, igm_ref)
     autoscaler_name = getattr(autoscaler, 'name', None)
@@ -71,7 +72,8 @@ class SetAutoscaling(base.Command):
         igm_ref,
         autoscaler_name,
         autoscaler,
-        scale_in=scale_in)
+        scale_in=scale_in,
+        predictive=predictive)
     return autoscaler_resource, new_one
 
   def _SetAutoscalerFromFile(
@@ -205,7 +207,8 @@ class SetAutoscalingAlpha(SetAutoscaling):
         queue_scaling_enabled=True,
         autoscaling_file_enabled=True,
         stackdriver_metrics_flags=True,
-        scale_in=True)
+        scale_in=True,
+        predictive=True)
     instance_groups_flags.MULTISCOPE_INSTANCE_GROUP_MANAGER_ARG.AddArgument(
         parser)
 
@@ -226,7 +229,12 @@ class SetAutoscalingAlpha(SetAutoscaling):
         igm_ref, client)
 
     autoscaler_resource, is_new = self.CreateAutoscalerResource(
-        client, holder.resources, igm_ref, args, scale_in=True)
+        client,
+        holder.resources,
+        igm_ref,
+        args,
+        scale_in=True,
+        predictive=True)
 
     managed_instance_groups_utils.ValidateGeneratedAutoscalerIsValid(
         args, autoscaler_resource)
@@ -249,7 +257,7 @@ class SetAutoscalingAlpha(SetAutoscaling):
 
 SetAutoscaling.detailed_help = {
     'brief': 'Set autoscaling parameters of a managed instance group',
-    'DESCRIPTION': """\
+    'DESCRIPTION': """
         *{command}* sets autoscaling parameters of specified managed instance
 group.
 
