@@ -23,6 +23,7 @@ from googlecloudsdk.api_lib.compute import org_security_policy_rule_utils as rul
 from googlecloudsdk.api_lib.compute.org_security_policies import client
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.compute.org_security_policies import flags
+from googlecloudsdk.command_lib.compute.org_security_policies import org_security_policies_utils
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@@ -44,11 +45,14 @@ class Update(base.UpdateCommand):
     flags.AddSrcIpRanges(parser)
     flags.AddDestIpRanges(parser)
     flags.AddDestPorts(parser)
+    flags.AddLayer4Configs(parser)
     flags.AddDirection(parser)
     flags.AddEnableLogging(parser)
     flags.AddTargetResources(parser)
+    flags.AddTargetServiceAccounts(parser)
     flags.AddDescription(parser)
     flags.AddNewPriority(parser, operation='update')
+    flags.AddOrganization(parser, required=False)
 
   def Run(self, args):
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
@@ -59,8 +63,10 @@ class Update(base.UpdateCommand):
     priority = rule_utils.ConvertPriorityToInt(ref.Name())
     src_ip_ranges = []
     dest_ip_ranges = []
-    dest_port_list = []
+    dest_ports_list = []
+    layer4_config_list = []
     target_resources = []
+    target_service_accounts = []
     enable_logging = False
     should_setup_match = False
     traffic_direct = None
@@ -72,11 +78,17 @@ class Update(base.UpdateCommand):
       dest_ip_ranges = args.dest_ip_ranges
       should_setup_match = True
     if args.IsSpecified('dest_ports'):
-      dest_port_list = rule_utils.ParseDestPorts(args.dest_ports,
-                                                 holder.client.messages)
       should_setup_match = True
+      dest_ports_list = rule_utils.ParseDestPorts(args.dest_ports,
+                                                  holder.client.messages)
+    if args.IsSpecified('layer4_configs'):
+      should_setup_match = True
+      layer4_config_list = rule_utils.ParseLayer4Configs(
+          args.layer4_configs, holder.client.messages)
     if args.IsSpecified('target_resources'):
       target_resources = args.target_resources
+    if args.IsSpecified('target_service_accounts'):
+      target_service_accounts = args.target_service_accounts
     if args.IsSpecified('enable_logging'):
       enable_logging = True
     if args.IsSpecified('new_priority'):
@@ -92,7 +104,8 @@ class Update(base.UpdateCommand):
           config=holder.client.messages.SecurityPolicyRuleMatcherConfig(
               srcIpRanges=src_ip_ranges,
               destIpRanges=dest_ip_ranges,
-              destPorts=dest_port_list))
+              destPorts=dest_ports_list,
+              layer4Configs=layer4_config_list))
     if args.IsSpecified('direction'):
       if args.direction == 'INGRESS':
         traffic_direct = holder.client.messages.SecurityPolicyRule.DirectionValueValuesEnum.INGRESS
@@ -105,10 +118,18 @@ class Update(base.UpdateCommand):
         match=matcher,
         direction=traffic_direct,
         targetResources=target_resources,
+        targetServiceAccounts=target_service_accounts,
         description=args.description,
         enableLogging=enable_logging)
 
+    org_security_policy = client.OrgSecurityPolicy(
+        ref=ref, compute_client=holder.client)
+    security_policy_id = org_security_policies_utils.GetSecurityPolicyId(
+        org_security_policy,
+        args.security_policy,
+        organization=args.organization)
+
     return security_policy_rule_client.Update(
         priority=priority,
-        security_policy=args.security_policy,
+        security_policy=security_policy_id,
         security_policy_rule=security_policy_rule)
