@@ -143,6 +143,7 @@ def ParseCreateNodePoolOptionsBase(args):
       metadata=metadata,
       max_pods_per_node=args.max_pods_per_node,
       enable_autoprovisioning=args.enable_autoprovisioning,
+      workload_metadata_from_node=args.workload_metadata_from_node,
       shielded_secure_boot=args.shielded_secure_boot,
       shielded_integrity_monitoring=args.shielded_integrity_monitoring,
       reservation_affinity=args.reservation_affinity,
@@ -164,6 +165,7 @@ class Create(base.CreateCommand):
     flags.AddPreemptibleFlag(parser, for_node_pool=True)
     flags.AddEnableAutoRepairFlag(parser, for_node_pool=True, for_create=True)
     flags.AddMinCpuPlatformFlag(parser, for_node_pool=True)
+    flags.AddWorkloadMetadataFromNodeFlag(parser)
     flags.AddNodeTaintsFlag(parser, for_node_pool=True)
     flags.AddNodePoolNodeIdentityFlags(parser)
     flags.AddNodePoolAutoprovisioningFlag(parser, hidden=False)
@@ -246,7 +248,7 @@ class CreateBeta(Create):
     flags.AddPreemptibleFlag(parser, for_node_pool=True)
     flags.AddEnableAutoRepairFlag(parser, for_node_pool=True, for_create=True)
     flags.AddMinCpuPlatformFlag(parser, for_node_pool=True)
-    flags.AddWorkloadMetadataFromNodeFlag(parser)
+    flags.AddWorkloadMetadataFromNodeFlag(parser, use_mode=False)
     flags.AddNodeTaintsFlag(parser, for_node_pool=True)
     flags.AddNodePoolNodeIdentityFlags(parser)
     flags.AddNodePoolAutoprovisioningFlag(parser, hidden=False)
@@ -255,13 +257,14 @@ class CreateBeta(Create):
     flags.AddSandboxFlag(parser)
     flags.AddNodePoolLocationsFlag(parser, for_create=True)
     flags.AddSurgeUpgradeFlag(parser, for_node_pool=True, default=1)
-    flags.AddMaxUnavailableUpgradeFlag(parser, for_node_pool=True,
-                                       is_create=True)
+    flags.AddMaxUnavailableUpgradeFlag(
+        parser, for_node_pool=True, is_create=True)
     flags.AddReservationAffinityFlags(parser, for_node_pool=True)
 
   def ParseCreateNodePoolOptions(self, args):
     ops = ParseCreateNodePoolOptionsBase(args)
     flags.WarnForNodeVersionAutoUpgrade(args)
+    flags.ValidateSurgeUpgradeSettings(args)
     ops.workload_metadata_from_node = args.workload_metadata_from_node
     ops.boot_disk_kms_key = args.boot_disk_kms_key
     ops.sandbox = args.sandbox
@@ -276,6 +279,7 @@ class CreateAlpha(Create):
   def ParseCreateNodePoolOptions(self, args):
     ops = ParseCreateNodePoolOptionsBase(args)
     flags.WarnForNodeVersionAutoUpgrade(args)
+    flags.ValidateSurgeUpgradeSettings(args)
     ops.workload_metadata_from_node = args.workload_metadata_from_node
     ops.local_ssd_volume_configs = args.local_ssd_volumes
     ops.boot_disk_kms_key = args.boot_disk_kms_key
@@ -296,7 +300,7 @@ class CreateAlpha(Create):
     flags.AddPreemptibleFlag(parser, for_node_pool=True)
     flags.AddEnableAutoRepairFlag(parser, for_node_pool=True, for_create=True)
     flags.AddMinCpuPlatformFlag(parser, for_node_pool=True)
-    flags.AddWorkloadMetadataFromNodeFlag(parser)
+    flags.AddWorkloadMetadataFromNodeFlag(parser, use_mode=False)
     flags.AddNodeTaintsFlag(parser, for_node_pool=True)
     flags.AddNodePoolNodeIdentityFlags(parser)
     flags.AddMaxPodsPerNodeFlag(parser, for_node_pool=True)
@@ -305,8 +309,8 @@ class CreateAlpha(Create):
     flags.AddEnableAutoUpgradeFlag(parser, for_node_pool=True, default=True)
     flags.AddLinuxSysctlFlags(parser, for_node_pool=True)
     flags.AddSurgeUpgradeFlag(parser, for_node_pool=True, default=1)
-    flags.AddMaxUnavailableUpgradeFlag(parser, for_node_pool=True,
-                                       is_create=True)
+    flags.AddMaxUnavailableUpgradeFlag(
+        parser, for_node_pool=True, is_create=True)
     flags.AddNodePoolLocationsFlag(parser, for_create=True)
     flags.AddNodeConfigFlag(parser)
     flags.AddReservationAffinityFlags(parser, for_node_pool=True)
