@@ -52,44 +52,44 @@ class Update(base.UpdateCommand, dm_base.DmCommand):
   """
 
   detailed_help = {
-      'EXAMPLES': """\
-          To update an existing deployment with a new config yaml file, run:
+      'EXAMPLES': """
+To update an existing deployment with a new config YAML file, run:
 
-            $ {command} my-deployment --config new_config.yaml
+  $ {command} my-deployment --config=new_config.yaml
 
-          To update an existing deployment with a new config template file, run:
+To update an existing deployment with a new config template file, run:
 
-            $ {command} my-deployment --template new_config.{jinja|py}
+  $ {command} my-deployment --template=new_config.{jinja|py}
 
-          To update an existing deployment with a composite type as a new config, run:
+To update an existing deployment with a composite type as a new config, run:
 
-            $ {command} my-deployment --composite-type <project-id>/composite:<new-config>
+  $ {command} my-deployment --composite-type=<project-id>/composite:<new-config>
 
 
-          To preview an update to an existing deployment without actually modifying the resources, run:
+To preview an update to an existing deployment without actually modifying the resources, run:
 
-            $ {command} my-deployment --config new_config.yaml --preview
+  $ {command} my-deployment --config=new_config.yaml --preview
 
-          To apply an update that has been previewed, provide the name of the previewed deployment, and no config file:
+To apply an update that has been previewed, provide the name of the previewed deployment, and no config file:
 
-            $ {command} my-deployment
+  $ {command} my-deployment
 
-          To specify different create, update, or delete policies, include any subset of the following flags;
+To specify different create, update, or delete policies, include any subset of the following flags:
 
-            $ {command} my-deployment --config new_config.yaml --create-policy acquire --delete-policy abandon
+  $ {command} my-deployment --config=new_config.yaml --create-policy=acquire --delete-policy=abandon
 
-          To perform an update without waiting for the operation to complete, run:
+To perform an update without waiting for the operation to complete, run:
 
-            $ {command} my-deployment --config new_config.yaml --async
+  $ {command} my-deployment --config=new_config.yaml --async
 
-          To update an existing deployment with a new config file and a fingerprint, run:
+To update an existing deployment with a new config file and a fingerprint, run:
 
-            $ {command} my-deployment --config new_config.yaml --fingerprint deployment-fingerprint
+  $ {command} my-deployment --config=new_config.yaml --fingerprint=deployment-fingerprint
 
-          Either the --config, --template, or --composite-type flag is required unless launching an already-previewed update to a deployment. If you want to update a deployment's metadata, such as the labels or description, you must run a separate command with --update-labels, --remove-labels, or --description, as applicable.
+Either the `--config`, `--template`, or `--composite-type` flag is required unless launching an already-previewed update to a deployment. If you want to update a deployment's metadata, such as the labels or description, you must run a separate command with `--update-labels`, `--remove-labels`, or `--description`, as applicable.
 
-          More information is available at https://cloud.google.com/deployment-manager/docs/deployments/updating-deployments.
-          """,
+More information is available at https://cloud.google.com/deployment-manager/docs/deployments/updating-deployments.
+""",
   }
 
   _delete_policy_flag_map = flags.GetDeleteFlagEnumMap(
