@@ -30,8 +30,78 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA,
-                    base.ReleaseTrack.ALPHA)
+def AddBaseArgs(parser):
+  flags.AddInstance(parser)
+  flags.AddUsername(parser)
+  flags.AddHost(parser)
+  flags.AddPassword(parser)
+
+
+def AddAlphaArgs(parser):
+  flags.AddType(parser)
+
+
+def RunBaseCreateCommand(args, release_track):
+  """Creates a user in a given instance.
+
+  Args:
+    args: argparse.Namespace, The arguments that this command was invoked with.
+    release_track: base.ReleaseTrack, the release track that this was run under.
+
+  Returns:
+    SQL user resource iterator.
+  """
+  client = api_util.SqlClient(api_util.API_VERSION_DEFAULT)
+  sql_client = client.sql_client
+  sql_messages = client.sql_messages
+
+  instance_ref = client.resource_parser.Parse(
+      args.instance,
+      params={'project': properties.VALUES.core.project.GetOrFail},
+      collection='sql.instances')
+  operation_ref = None
+
+  host = users.GetHostValue(args)
+  if release_track == base.ReleaseTrack.ALPHA:
+    user_type = users.ParseUserType(sql_messages, args)
+    new_user = sql_messages.User(
+        kind='sql#user',
+        project=instance_ref.project,
+        instance=args.instance,
+        name=args.username,
+        host=host,
+        password=args.password,
+        type=user_type)
+  else:
+    new_user = sql_messages.User(
+        kind='sql#user',
+        project=instance_ref.project,
+        instance=args.instance,
+        name=args.username,
+        host=host,
+        password=args.password)
+
+  result_operation = sql_client.users.Insert(new_user)
+  operation_ref = client.resource_parser.Create(
+      'sql.operations',
+      operation=result_operation.name,
+      project=instance_ref.project)
+  if args.async_:
+    result = sql_client.operations.Get(
+        sql_messages.SqlOperationsGetRequest(
+            project=operation_ref.project, operation=operation_ref.operation))
+  else:
+    operations.OperationsV1Beta4.WaitForOperation(sql_client, operation_ref,
+                                                  'Creating Cloud SQL user')
+    result = new_user
+    result.kind = None
+
+  log.CreatedResource(args.username, kind='user', is_async=args.async_)
+
+  return result
+
+
+@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA)
 class Create(base.CreateCommand):
   """Creates a user in a given instance.
 
@@ -41,57 +111,28 @@ class Create(base.CreateCommand):
 
   @staticmethod
   def Args(parser):
-    flags.AddInstance(parser)
-    flags.AddUsername(parser)
-    flags.AddHost(parser)
-    flags.AddPassword(parser)
+    AddBaseArgs(parser)
     base.ASYNC_FLAG.AddToParser(parser)
     parser.display_info.AddCacheUpdater(flags.UserCompleter)
 
   def Run(self, args):
-    """Creates a user in a given instance.
+    return RunBaseCreateCommand(args, self.ReleaseTrack())
 
-    Args:
-      args: argparse.Namespace, The arguments that this command was invoked
-          with.
 
-    Returns:
-      SQL user resource iterator.
-    """
-    client = api_util.SqlClient(api_util.API_VERSION_DEFAULT)
-    sql_client = client.sql_client
-    sql_messages = client.sql_messages
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class CreateAlpha(base.CreateCommand):
+  """Creates a user in a given instance.
 
-    instance_ref = client.resource_parser.Parse(
-        args.instance,
-        params={'project': properties.VALUES.core.project.GetOrFail},
-        collection='sql.instances')
-    operation_ref = None
+  Creates a user in a given instance with specified username, host, and
+  password.
+  """
 
-    host = users.GetHostValue(args)
-    new_user = sql_messages.User(
-        kind='sql#user',
-        project=instance_ref.project,
-        instance=args.instance,
-        name=args.username,
-        host=host,
-        password=args.password)
+  @staticmethod
+  def Args(parser):
+    AddBaseArgs(parser)
+    AddAlphaArgs(parser)
+    base.ASYNC_FLAG.AddToParser(parser)
+    parser.display_info.AddCacheUpdater(flags.UserCompleter)
 
-    result_operation = sql_client.users.Insert(new_user)
-    operation_ref = client.resource_parser.Create(
-        'sql.operations',
-        operation=result_operation.name,
-        project=instance_ref.project)
-    if args.async_:
-      result = sql_client.operations.Get(
-          sql_messages.SqlOperationsGetRequest(
-              project=operation_ref.project, operation=operation_ref.operation))
-    else:
-      operations.OperationsV1Beta4.WaitForOperation(sql_client, operation_ref,
-                                                    'Creating Cloud SQL user')
-      result = new_user
-      result.kind = None
-
-    log.CreatedResource(args.username, kind='user', is_async=args.async_)
-
-    return result
+  def Run(self, args):
+    return RunBaseCreateCommand(args, self.ReleaseTrack())
